==> muffin-0.5.zip: muffin-0.5/src/muffin/filter/AnimationKiller.java <==
/* AnimationKiller.java */

/* 
 * Copyright (C) 1997 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin.filter;

import muffin.*;

public class AnimationKiller implements FilterFactory
{
    FilterManager manager;
    Prefs prefs;
    AnimationKillerFrame frame = null;

    public void setManager (FilterManager manager)
    {
	this.manager = manager;
    }
    
    public void setPrefs (Prefs prefs)
    {
	this.prefs = prefs;

	boolean o = prefs.getOverride ();
	prefs.setOverride (false);
	prefs.putInteger ("AnimationKiller.maxLoops", 1);
	prefs.putBoolean ("AnimationKiller.break", false);
	prefs.setOverride (o);
    }

    public Prefs getPrefs ()
    {
	return prefs;
    }

    public void viewPrefs ()
    {
	if (frame == null)
	{
	    frame = new AnimationKillerFrame (prefs, this);
	}
	frame.setVisible (true);
    }
    
    public Filter createFilter ()
    {
	Filter f = new AnimationKillerFilter (this);
	f.setPrefs (prefs);
	return f;
    }

    void save ()
    {
	manager.save (this);
    }

    void process (String s)
    {
	if (frame != null)
	{
	    frame.text.append (s);
	}
    }
}

==> muffin-0.6.zip: muffin-0.6/src/muffin/filter/AnimationKiller.java <==
/* AnimationKiller.java */

/* 
 * Copyright (C) 1996-98 Mark Boyns <boyns@sdsu.edu>
 *
 * This file is part of Muffin.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package muffin.filter;

import muffin.*;

public class AnimationKiller implements FilterFactory
{
    FilterManager manager;
    Prefs prefs;
    AnimationKillerFrame frame = null;
    MessageArea messages = null;

    public void setManager (FilterManager manager)
    {
	this.manager = manager;
    }
    
    public void setPrefs (Prefs prefs)
    {
	this.prefs = prefs;

	boolean o = prefs.getOverride ();
	prefs.setOverride (false);
	prefs.putInteger ("AnimationKiller.maxLoops", 1);
	prefs.putBoolean ("AnimationKiller.break", false);
	prefs.putInteger ("AnimationKiller.historySize", 500);
	prefs.setOverride (o);

	messages = new MessageArea (prefs.getInteger ("AnimationKiller.historySize"));
    }

    public Prefs getPrefs ()
    {
	return prefs;
    }

    public void viewPrefs ()
    {
	if (frame == null)
	{
	    frame = new AnimationKillerFrame (prefs, this);
	}
	frame.setVisible (true);
    }
    
    public Filter createFilter ()
    {
	Filter f = new AnimationKillerFilter (this);
	f.setPrefs (prefs);
	return f;
    }

    public void shutdown ()
    {
	if (frame != null)
	{
	    frame.dispose ();
	}
    }

    void save ()
    {
	manager.save (this);
    }

    void process (String s)
    {
	messages.append (s);
    }
}
